@@ -356,6 +356,8 @@ class TextPropertiesWidget2(QtWidgets.QWidget):
 
     def setTarget(self, element: Artist):
         """ set the target artist for this widget """
+        if len(element) == 0:
+            return
         if isinstance(element, list):
             self.target_list = element
             element = element[0]
@@ -640,7 +642,7 @@ class QTickEdit(QtWidgets.QWidget):
             try:
                 l = float(l)
             except ValueError:
-                pass
+                continue
             if min <= t <= max:
                 if l != t:
                     text.append("%s \"%s\"" % (str(t), l_text))
@@ -691,8 +693,9 @@ class QTickEdit(QtWidgets.QWidget):
                 except ValueError as err:
                     pass
                 else:
-                    ticks.append(tick)
-                    labels.append(label)
+                    if not np.isnan(tick):
+                        ticks.append(tick)
+                        labels.append(label)
         except Exception as err:
             pass
         return ticks, labels
@@ -1185,7 +1188,8 @@ class QItemProperties(QtWidgets.QWidget):
         elements = [element.target for element in self.element.figure.selection.targets
                     if isinstance(element.target, Axes)]
         for element in elements:
-            if self.element.xaxis._gridOnMajor:
+            # _gridOnMajor for older matplotlib version (<=3.3.2) or _major_tick_kw["gridOn"] for newer matplotlib version (>=3.3.4)
+            if getattr(self.element.xaxis, "_gridOnMajor", False) or getattr(self.element.xaxis, "_major_tick_kw", {"gridOn": False})['gridOn']:
                 element.grid(False)
                 self.fig.change_tracker.addChange(element, ".grid(False)")
             else:
@@ -1342,7 +1346,11 @@ class ToolBar(QtWidgets.QToolBar):
         """ get an icon with the given filename """
         pm = QtGui.QPixmap(os.path.join(os.path.dirname(__file__), "icons", name))
         if hasattr(pm, 'setDevicePixelRatio'):
-            pm.setDevicePixelRatio(self.canvas._dpi_ratio)
+            try:  # older mpl < 3.5.0
+                pm.setDevicePixelRatio(self.canvas._dpi_ratio)
+            except AttributeError:
+                pm.setDevicePixelRatio(self.canvas.device_pixel_ratio)
+
         return QtGui.QIcon(pm)
 
     def setSelect(self):
