@@ -84,7 +84,7 @@ def initialize(use_global_variable_names=False):
     sf = Figure.savefig
 
     def savefig(self, filename, *args, **kwargs):
-        self._last_saved_figure = filename
+        self._last_saved_figure = getattr(self, "_last_saved_figure", []) + [(filename, args, kwargs)]
         sf(self, filename, *args, **kwargs)
 
     Figure.savefig = savefig
@@ -739,7 +739,13 @@ class PlotWindow(QtWidgets.QWidget):
         self.button_derasterize.setDisabled(True)
 
         self.treeView = MyTreeView(self, self.layout_tools, self.fig)
-        self.treeView.item_selected = self.elementSelected
+
+        self.no_figure_dragger_selection_update = False
+        def item_selected(x):
+            self.elementSelected(x)
+            if not self.no_figure_dragger_selection_update:
+                self.fig.figure_dragger.select_element(x)
+        self.treeView.item_selected = item_selected
 
         self.input_properties = QItemProperties(self.layout_tools, self.fig, self.treeView, self)
         self.input_align = Align(self.layout_tools, self.fig)
@@ -798,15 +804,12 @@ class PlotWindow(QtWidgets.QWidget):
     def actionSave(self):
         """ save the code for the figure """
         self.fig.change_tracker.save()
-        if getattr(self.fig, "_last_saved_figure", None):
-            if os.path.splitext(self.fig._last_saved_figure)[1] == ".pdf":
-                self.fig.savefig(self.fig._last_saved_figure, dpi=300)
-            else:
-                self.fig.savefig(self.fig._last_saved_figure)
+        for _last_saved_figure, args, kwargs in getattr(self.fig, "_last_saved_figure", []):
+            self.fig.savefig(_last_saved_figure, *args, **kwargs)
 
     def actionSaveImage(self):
         """ save figure as an image """
-        path = QtWidgets.QFileDialog.getSaveFileName(self, "Save Image", getattr(self.fig, "_last_saved_figure", None),
+        path = QtWidgets.QFileDialog.getSaveFileName(self, "Save Image", getattr(self.fig, "_last_saved_figure", [(None,)])[0][0],
                                                      "Images (*.png *.jpg *.pdf)")
         if isinstance(path, tuple):
             path = str(path[0])
@@ -1075,8 +1078,11 @@ class PlotWindow(QtWidgets.QWidget):
 
         def wrap(func):
             def newfunc(element, event=None):
+                self.no_figure_dragger_selection_update = True
                 self.select_element(element)
-                return func(element, event)
+                ret = func(element, event)
+                self.no_figure_dragger_selection_update = False
+                return ret
 
             return newfunc
 
